@@ -14,6 +14,7 @@
 # limitations under the License.
 
 from cfy_lint.yamllint_ext.autofix.truthy import fix_truthy
+from cfy_lint.yamllint_ext.autofix.colons import fix_colons
 from cfy_lint.yamllint_ext.autofix.indentation import fix_indentation
 from cfy_lint.yamllint_ext.autofix.trailing_spaces import fix_trailing_spaces
 from cfy_lint.yamllint_ext.autofix.deprecated_node_types import \
@@ -29,3 +30,4 @@ def fix_problem(problem):
         fix_trailing_spaces(problem)
         fix_deprecated_node_types(problem)
         fix_deprecated_relationships(problem)
+        fix_colons(problem)
