@@ -19,7 +19,7 @@ from cfy_lint.yamllint_ext.autofix.utils import filelines
 def fix_add_label(problems):
     counter = 0
     for problem in problems:
-        if problem.rule == 'inputs' and ' is missing a label.' in \
+        if problem.rule == 'inputs' and ' is missing a display_label.' in \
                 problem.message:
             with filelines(problem.file) as lines:
                 line = lines[problem.line - 1 + counter]
